import pydantic
import typing
import typing_extensions

from .v1_ai_headshot_generator_create_body_assets import (
    V1AiHeadshotGeneratorCreateBodyAssets,
    _SerializerV1AiHeadshotGeneratorCreateBodyAssets,
)
from .v1_ai_headshot_generator_create_body_style import (
    V1AiHeadshotGeneratorCreateBodyStyle,
    _SerializerV1AiHeadshotGeneratorCreateBodyStyle,
)


class V1AiHeadshotGeneratorCreateBody(typing_extensions.TypedDict):
    """
    V1AiHeadshotGeneratorCreateBody
    """

    assets: typing_extensions.Required[V1AiHeadshotGeneratorCreateBodyAssets]
    """
    Provide the assets for headshot photo
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    style: typing_extensions.NotRequired[V1AiHeadshotGeneratorCreateBodyStyle]


class _SerializerV1AiHeadshotGeneratorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiHeadshotGeneratorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AiHeadshotGeneratorCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    style: typing.Optional[_SerializerV1AiHeadshotGeneratorCreateBodyStyle] = (
        pydantic.Field(alias="style", default=None)
    )



import typing
import re
from typing_extensions import Literal

import httpx

from .binary_response import BinaryResponse


def remove_none_from_dict(
    original: typing.Dict[str, typing.Optional[typing.Any]],
) -> typing.Dict[str, typing.Any]:
    new: typing.Dict[str, typing.Any] = {}
    for key, value in original.items():
        if value is not None:
            new[key] = value
    return new


def get_response_type(headers: httpx.Headers) -> Literal["json", "text", "binary"]:
    """Check response type based on content type"""
    content_type = headers.get("content-type")

    if re.search("^application/(.+[+])?json", content_type):
        return "json"
    elif re.search("^text/(.+)", content_type):
        return "text"
    else:
        return "binary"


def is_union_type(type_hint: typing.Any) -> bool:
    """Check if a type hint is a Union type."""
    return hasattr(type_hint, "__origin__") and type_hint.__origin__ is typing.Union


def filter_binary_response(cast_to: typing.Type) -> typing.Type:
    """
    Filters out BinaryResponse from a Union type.
    If cast_to is not a Union, returns it unchanged.
    """
    if not is_union_type(cast_to):
        return cast_to

    types = typing.get_args(cast_to)
    filtered = tuple(t for t in types if t != BinaryResponse)

    # If everything was filtered out, return original type
    if not filtered:
        return cast_to
    # If only one type remains, return it directly
    if len(filtered) == 1:
        return typing.cast(typing.Type, filtered[0])
    # Otherwise return new Union with filtered types
    return typing.cast(typing.Type, typing.Union[filtered])  # type: ignore



import enum


class Environment(enum.Enum):
    """Pre-defined base URLs for the API"""

    ENVIRONMENT = "https://api.magichour.ai"
    MOCK_SERVER = "https://api.sideko.dev/v1/mock/magichour/magic-hour/0.21.0"



import pydantic
import typing
import typing_extensions


class V1VideoToVideoCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1VideoToVideoCreateBodyStyle
    """

    art_style: typing_extensions.Required[
        typing_extensions.Literal[
            "3D Render",
            "Airbender",
            "Android",
            "Anime Warrior",
            "Armored Knight",
            "Assassin's Creed",
            "Avatar",
            "Black Spiderman",
            "Boba Fett",
            "Celestial Skin",
            "Chinese Swordsmen",
            "Clay",
            "Comic",
            "Cyberpunk",
            "Cypher",
            "Dark Fantasy",
            "Dragonball Z",
            "Future Bot",
            "Futuristic Fantasy",
            "GTA",
            "Ghost",
            "Gundam",
            "Hologram",
            "Illustration",
            "Impressionism",
            "Ink",
            "Ink Poster",
            "Jinx",
            "Knight",
            "Lego",
            "Link",
            "Marble",
            "Mario",
            "Master Chief",
            "Mech",
            "Minecraft",
            "Mystique",
            "Naruto",
            "Neon Dream",
            "Oil Painting",
            "On Fire",
            "Origami",
            "Pixar",
            "Pixel",
            "Power Armor",
            "Power Ranger",
            "Retro Anime",
            "Retro Sci-Fi",
            "Samurai",
            "Samurai Bot",
            "Solid Snake",
            "Spartan",
            "Starfield",
            "Street Fighter",
            "Studio Ghibli",
            "Sub-Zero",
            "The Void",
            "Tomb Raider",
            "Underwater",
            "Van Gogh",
            "Viking",
            "Watercolor",
            "Wu Kong",
            "Zelda",
        ]
    ]

    model: typing_extensions.Required[
        typing_extensions.Literal[
            "Absolute Reality", "Dreamshaper", "Flat 2D Anime", "default"
        ]
    ]
    """
    * `Dreamshaper` - a good all-around model that works for both animations as well as realism. 
    * `Absolute Reality` - better at realism, but you'll often get similar results with Dreamshaper as well. 
    * `Flat 2D Anime` - best for a flat illustration style that's common in most anime.
    * `default` - use the default recommended model for the selected art style.
    """

    prompt: typing_extensions.Required[typing.Optional[str]]
    """
    The prompt used for the video. Prompt is required if `prompt_type` is `custom` or `append_default`. If `prompt_type` is `default`, then the `prompt` value passed will be ignored.
    """

    prompt_type: typing_extensions.Required[
        typing_extensions.Literal["append_default", "custom", "default"]
    ]
    """
    * `default` - Use the default recommended prompt for the art style.
    * `custom` - Only use the prompt passed in the API. Note: for v1, lora prompt will still be auto added to apply the art style properly.
    * `append_default` - Add the default recommended prompt to the end of the prompt passed in the API.
    """

    version: typing_extensions.Required[
        typing_extensions.Literal["default", "v1", "v2"]
    ]
    """
    * `v1` - more detail, closer prompt adherence, and frame-by-frame previews.
    * `v2` - faster, more consistent, and less noisy.
    * `default` - use the default version for the selected art style.
    """


class _SerializerV1VideoToVideoCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1VideoToVideoCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    art_style: typing_extensions.Literal[
        "3D Render",
        "Airbender",
        "Android",
        "Anime Warrior",
        "Armored Knight",
        "Assassin's Creed",
        "Avatar",
        "Black Spiderman",
        "Boba Fett",
        "Celestial Skin",
        "Chinese Swordsmen",
        "Clay",
        "Comic",
        "Cyberpunk",
        "Cypher",
        "Dark Fantasy",
        "Dragonball Z",
        "Future Bot",
        "Futuristic Fantasy",
        "GTA",
        "Ghost",
        "Gundam",
        "Hologram",
        "Illustration",
        "Impressionism",
        "Ink",
        "Ink Poster",
        "Jinx",
        "Knight",
        "Lego",
        "Link",
        "Marble",
        "Mario",
        "Master Chief",
        "Mech",
        "Minecraft",
        "Mystique",
        "Naruto",
        "Neon Dream",
        "Oil Painting",
        "On Fire",
        "Origami",
        "Pixar",
        "Pixel",
        "Power Armor",
        "Power Ranger",
        "Retro Anime",
        "Retro Sci-Fi",
        "Samurai",
        "Samurai Bot",
        "Solid Snake",
        "Spartan",
        "Starfield",
        "Street Fighter",
        "Studio Ghibli",
        "Sub-Zero",
        "The Void",
        "Tomb Raider",
        "Underwater",
        "Van Gogh",
        "Viking",
        "Watercolor",
        "Wu Kong",
        "Zelda",
    ] = pydantic.Field(
        alias="art_style",
    )
    model: typing_extensions.Literal[
        "Absolute Reality", "Dreamshaper", "Flat 2D Anime", "default"
    ] = pydantic.Field(
        alias="model",
    )
    prompt: typing.Optional[str] = pydantic.Field(
        alias="prompt",
    )
    prompt_type: typing_extensions.Literal["append_default", "custom", "default"] = (
        pydantic.Field(
            alias="prompt_type",
        )
    )
    version: typing_extensions.Literal["default", "v1", "v2"] = pydantic.Field(
        alias="version",
    )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiFaceEditorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1AiFaceEditorCreateBodyAssets,
        style: params.V1AiFaceEditorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiFaceEditorCreateResponse:
        """
        AI Face Editor

        Edit facial features of an image using AI. Each edit costs 1 frame. The height/width of the output image depends on your subscription. Please refer to our [pricing](/pricing) page for more details

        POST /v1/ai-face-editor

        Args:
            name: The name of image
            assets: Provide the assets for face editor
            style: Face editing parameters
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_face_editor.create(
            assets={"image_file_path": "api-assets/id/1234.png"},
            style={
                "enhance_face": False,
                "eye_gaze_horizontal": 0.0,
                "eye_gaze_vertical": 0.0,
                "eye_open_ratio": 0.0,
                "eyebrow_direction": 0.0,
                "head_pitch": 0.0,
                "head_roll": 0.0,
                "head_yaw": 0.0,
                "lip_open_ratio": 0.0,
                "mouth_grim": 0.0,
                "mouth_position_horizontal": 0.0,
                "mouth_position_vertical": 0.0,
                "mouth_pout": 0.0,
                "mouth_purse": 0.0,
                "mouth_smile": 0.0,
            },
            name="Face Editor image",
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "assets": assets, "style": style},
            dump_with=params._SerializerV1AiFaceEditorCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-face-editor",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiFaceEditorCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiFaceEditorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1AiFaceEditorCreateBodyAssets,
        style: params.V1AiFaceEditorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiFaceEditorCreateResponse:
        """
        AI Face Editor

        Edit facial features of an image using AI. Each edit costs 1 frame. The height/width of the output image depends on your subscription. Please refer to our [pricing](/pricing) page for more details

        POST /v1/ai-face-editor

        Args:
            name: The name of image
            assets: Provide the assets for face editor
            style: Face editing parameters
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_face_editor.create(
            assets={"image_file_path": "api-assets/id/1234.png"},
            style={
                "enhance_face": False,
                "eye_gaze_horizontal": 0.0,
                "eye_gaze_vertical": 0.0,
                "eye_open_ratio": 0.0,
                "eyebrow_direction": 0.0,
                "head_pitch": 0.0,
                "head_roll": 0.0,
                "head_yaw": 0.0,
                "lip_open_ratio": 0.0,
                "mouth_grim": 0.0,
                "mouth_position_horizontal": 0.0,
                "mouth_position_vertical": 0.0,
                "mouth_pout": 0.0,
                "mouth_purse": 0.0,
                "mouth_smile": 0.0,
            },
            name="Face Editor image",
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "assets": assets, "style": style},
            dump_with=params._SerializerV1AiFaceEditorCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-face-editor",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiFaceEditorCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing
import typing_extensions

from .v1_text_to_video_create_body_style import (
    V1TextToVideoCreateBodyStyle,
    _SerializerV1TextToVideoCreateBodyStyle,
)


class V1TextToVideoCreateBody(typing_extensions.TypedDict):
    """
    V1TextToVideoCreateBody
    """

    end_seconds: typing_extensions.Required[float]
    """
    The total duration of the output video in seconds.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    orientation: typing_extensions.Required[
        typing_extensions.Literal["landscape", "portrait", "square"]
    ]
    """
    Determines the orientation of the output video
    """

    style: typing_extensions.Required[V1TextToVideoCreateBodyStyle]


class _SerializerV1TextToVideoCreateBody(pydantic.BaseModel):
    """
    Serializer for V1TextToVideoCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    orientation: typing_extensions.Literal["landscape", "portrait", "square"] = (
        pydantic.Field(
            alias="orientation",
        )
    )
    style: _SerializerV1TextToVideoCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic


class V1AiGifGeneratorCreateResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    frame_cost: int = pydantic.Field(
        alias="frame_cost",
    )
    """
    The frame cost of the image generation
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    Unique ID of the image. This value can be used in the [get image project API](https://docs.magichour.ai/api-reference/image-projects/get-image-details) to fetch additional details such as status
    """



from typing import Any, Dict, Type, Union, List, Mapping

import httpx
from typing_extensions import TypedDict, Required, NotRequired
from pydantic import TypeAdapter, BaseModel

from .type_utils import NotGiven
from .query import QueryParams, QueryParamStyle, encode_query_param

"""
Request configuration and utility functions for handling HTTP requests.
This module provides type definitions and helper functions for building
and processing HTTP requests in a type-safe manner.
"""


class RequestConfig(TypedDict):
    """
    Configuration for HTTP requests.

    Defines all possible parameters that can be passed to an HTTP request,
    including required method and URL, as well as optional parameters like
    content, headers, authentication, etc.
    """

    method: Required[str]
    url: Required[httpx._types.URLTypes]
    content: NotRequired[httpx._types.RequestContent]
    data: NotRequired[httpx._types.RequestData]
    files: NotRequired[httpx._types.RequestFiles]
    json: NotRequired[Any]
    params: NotRequired[QueryParams]
    headers: NotRequired[Dict[str, str]]
    cookies: NotRequired[Dict[str, str]]
    auth: NotRequired[httpx._types.AuthTypes]
    follow_redirects: NotRequired[bool]
    timeout: NotRequired[httpx._types.TimeoutTypes]
    extensions: NotRequired[httpx._types.RequestExtensions]


class RequestOptions(TypedDict):
    """
    Additional options for customizing request behavior.

    Provides configuration for timeouts and additional headers/parameters
    that should be included with requests.

    Attributes:
        timeout: Number of seconds to await an API call before timing out
        additional_headers: Extra headers to include in the request
        additional_params: Extra query parameters to include in the request
    """

    timeout: NotRequired[int]
    additional_headers: NotRequired[Dict[str, str]]
    additional_params: NotRequired[QueryParams]


def default_request_options() -> RequestOptions:
    """
    Provides default request options.

    Returns an empty dictionary as the base configuration, allowing defaults
    to be handled by the underlying HTTP client.
    """
    return {}


def model_dump(item: Any) -> Any:
    """
    Recursively converts Pydantic models to dictionaries.

    Handles nested structures including lists and individual models,
    preserving alias information and excluding unset values.
    """
    if isinstance(item, list):
        return [model_dump(i) for i in item]
    if isinstance(item, BaseModel):
        return item.model_dump(exclude_unset=True, by_alias=True)
    else:
        return item


def to_encodable(
    *, item: Any, dump_with: Union[Type, Union[Type, Any], List[Type]]
) -> Any:
    """
    Validates and converts an item to an encodable format using a specified type.
    Uses Pydantic's TypeAdapter for validation and converts the result
    to a format suitable for encoding in requests.
    """
    filtered_item = filter_not_given(item)
    adapter: TypeAdapter = TypeAdapter(dump_with)
    validated_item = adapter.validate_python(filtered_item)
    return model_dump(validated_item)


def to_form_urlencoded(
    *,
    item: Any,
    dump_with: Union[Type, Union[Type, Any]],
    style: Mapping[str, QueryParamStyle],
    explode: Mapping[str, bool],
) -> Mapping[str, Any]:
    """
    Encodes object as x-www-form-urlencoded according to style and explode options
    """
    encoded = to_encodable(item=item, dump_with=dump_with)

    if not isinstance(encoded, dict):
        raise TypeError("x-www-form-urlencoded data must be an object at the top level")

    form_data: QueryParams = {}

    for key, val in encoded.items():
        key_style = style.get(key, "form")
        key_explode = explode.get(key, key_style == "form")
        encode_query_param(form_data, key, val, style=key_style, explode=key_explode)

    return form_data


def to_content(*, file: httpx._types.FileTypes) -> httpx._types.RequestContent:
    """
    Converts the various ways files can be provided to something that is accepted by
    the httpx.request content kwarg
    """
    if isinstance(file, tuple):
        file_content: httpx._types.FileContent = file[1]
    else:
        file_content = file

    if hasattr(file_content, "read") and callable(file_content.read):
        return file_content.read()
    else:
        return file_content


def filter_not_given(value: Any) -> Any:
    """Helper function to recursively filter out NotGiven values"""
    if isinstance(value, NotGiven):
        return None  # This will trigger filtering at the container level
    elif isinstance(value, dict):
        return {
            k: filter_not_given(v)
            for k, v in value.items()
            if not isinstance(v, NotGiven)
        }
    elif isinstance(value, (list, tuple)):
        return type(value)(
            filter_not_given(item) for item in value if not isinstance(item, NotGiven)
        )
    return value


def _get_default_for_type(value_type: Any) -> Any:
    """Helper to provide appropriate default values for required fields"""
    if value_type is dict or isinstance(value_type, dict):
        return {}
    elif value_type is list or isinstance(value_type, list):
        return []
    return None



import pydantic
import typing
import typing_extensions


class V1TextToVideoCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1TextToVideoCreateBodyStyle
    """

    prompt: typing_extensions.Required[str]
    """
    The prompt used for the video.
    """

    quality_mode: typing_extensions.NotRequired[
        typing_extensions.Literal["quick", "studio"]
    ]
    """
    * `quick` - Fastest option for rapid results. Takes ~3 minutes per 5s of video.
    *  `studio` - Polished visuals with longer runtime. Takes ~8.5 minutes per 5s of video.
    """


class _SerializerV1TextToVideoCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1TextToVideoCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    prompt: str = pydantic.Field(
        alias="prompt",
    )
    quality_mode: typing.Optional[typing_extensions.Literal["quick", "studio"]] = (
        pydantic.Field(alias="quality_mode", default=None)
    )



import pydantic
import typing_extensions


class V1AiGifGeneratorCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1AiGifGeneratorCreateBodyStyle
    """

    prompt: typing_extensions.Required[str]
    """
    The prompt used for the GIF.
    """


class _SerializerV1AiGifGeneratorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiGifGeneratorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    prompt: str = pydantic.Field(
        alias="prompt",
    )



import pydantic
import typing
import typing_extensions


class V1AiPhotoEditorCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1AiPhotoEditorCreateBodyStyle
    """

    image_description: typing_extensions.Required[str]
    """
    Use this to describe what your input image is. This helps maintain aspects of the image you don't want to change.
    """

    likeness_strength: typing_extensions.Required[float]
    """
    Determines the input image's influence. Higher values align the output more with the initial image.
    """

    negative_prompt: typing_extensions.NotRequired[str]
    """
    What you want to avoid seeing in the final output; has a minor effect.
    """

    prompt: typing_extensions.Required[str]
    """
    What you want your final output to look like. We recommend starting with the image description and making minor edits for best results.
    """

    prompt_strength: typing_extensions.Required[float]
    """
    Determines the prompt's influence. Higher values align the output more with the prompt.
    """

    steps: typing_extensions.NotRequired[int]
    """
    Number of iterations used to generate the output. Higher values improve quality and increase the strength of the prompt but increase processing time.
    """

    upscale_factor: typing_extensions.NotRequired[int]
    """
    The multiplier applied to an image's original dimensions during the upscaling process. For example, a scale of 2 doubles the width and height (e.g., from 512x512 to 1024x1024).
    """

    upscale_fidelity: typing_extensions.NotRequired[float]
    """
    Upscale fidelity refers to the level of quality desired in the generated image. Fidelity value of 1 means more details.
    """


class _SerializerV1AiPhotoEditorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiPhotoEditorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    image_description: str = pydantic.Field(
        alias="image_description",
    )
    likeness_strength: float = pydantic.Field(
        alias="likeness_strength",
    )
    negative_prompt: typing.Optional[str] = pydantic.Field(
        alias="negative_prompt", default=None
    )
    prompt: str = pydantic.Field(
        alias="prompt",
    )
    prompt_strength: float = pydantic.Field(
        alias="prompt_strength",
    )
    steps: typing.Optional[int] = pydantic.Field(alias="steps", default=None)
    upscale_factor: typing.Optional[int] = pydantic.Field(
        alias="upscale_factor", default=None
    )
    upscale_fidelity: typing.Optional[float] = pydantic.Field(
        alias="upscale_fidelity", default=None
    )



import pydantic
import typing
import typing_extensions

from .v1_image_to_video_create_body_assets import (
    V1ImageToVideoCreateBodyAssets,
    _SerializerV1ImageToVideoCreateBodyAssets,
)
from .v1_image_to_video_create_body_style import (
    V1ImageToVideoCreateBodyStyle,
    _SerializerV1ImageToVideoCreateBodyStyle,
)


class V1ImageToVideoCreateBody(typing_extensions.TypedDict):
    """
    V1ImageToVideoCreateBody
    """

    assets: typing_extensions.Required[V1ImageToVideoCreateBodyAssets]
    """
    Provide the assets for image-to-video.
    """

    end_seconds: typing_extensions.Required[float]
    """
    The total duration of the output video in seconds.
    """

    height: typing_extensions.NotRequired[int]
    """
    This field does not affect the output video's resolution. The video's orientation will match that of the input image.
    
    It is retained solely for backward compatibility and will be deprecated in the future.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    style: typing_extensions.Required[V1ImageToVideoCreateBodyStyle]
    """
    Attributed used to dictate the style of the output
    """

    width: typing_extensions.NotRequired[int]
    """
    This field does not affect the output video's resolution. The video's orientation will match that of the input image.
    
    It is retained solely for backward compatibility and will be deprecated in the future.
    """


class _SerializerV1ImageToVideoCreateBody(pydantic.BaseModel):
    """
    Serializer for V1ImageToVideoCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1ImageToVideoCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    height: typing.Optional[int] = pydantic.Field(alias="height", default=None)
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    style: _SerializerV1ImageToVideoCreateBodyStyle = pydantic.Field(
        alias="style",
    )
    width: typing.Optional[int] = pydantic.Field(alias="width", default=None)



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class ImageToVideoClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1ImageToVideoCreateBodyAssets,
        end_seconds: float,
        style: params.V1ImageToVideoCreateBodyStyle,
        height: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        width: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1ImageToVideoCreateResponse:
        """
        Image-to-Video

        Create a Image To Video video. The estimated frame cost is calculated using 30 FPS. This amount is deducted from your account balance when a video is queued. Once the video is complete, the cost will be updated based on the actual number of frames rendered.

        Get more information about this mode at our [product page](/products/image-to-video).


        POST /v1/image-to-video

        Args:
            height: This field does not affect the output video's resolution. The video's orientation will match that of the input image.

        It is retained solely for backward compatibility and will be deprecated in the future.
            name: The name of video
            width: This field does not affect the output video's resolution. The video's orientation will match that of the input image.

        It is retained solely for backward compatibility and will be deprecated in the future.
            assets: Provide the assets for image-to-video.
            end_seconds: The total duration of the output video in seconds.
            style: Attributed used to dictate the style of the output
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.image_to_video.create(
            assets={"image_file_path": "api-assets/id/1234.png"},
            end_seconds=5.0,
            style={"prompt": "a dog running"},
            height=960,
            name="Image To Video video",
            width=512,
        )
        ```
        """
        _json = to_encodable(
            item={
                "height": height,
                "name": name,
                "width": width,
                "assets": assets,
                "end_seconds": end_seconds,
                "style": style,
            },
            dump_with=params._SerializerV1ImageToVideoCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/image-to-video",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1ImageToVideoCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncImageToVideoClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1ImageToVideoCreateBodyAssets,
        end_seconds: float,
        style: params.V1ImageToVideoCreateBodyStyle,
        height: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        width: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1ImageToVideoCreateResponse:
        """
        Image-to-Video

        Create a Image To Video video. The estimated frame cost is calculated using 30 FPS. This amount is deducted from your account balance when a video is queued. Once the video is complete, the cost will be updated based on the actual number of frames rendered.

        Get more information about this mode at our [product page](/products/image-to-video).


        POST /v1/image-to-video

        Args:
            height: This field does not affect the output video's resolution. The video's orientation will match that of the input image.

        It is retained solely for backward compatibility and will be deprecated in the future.
            name: The name of video
            width: This field does not affect the output video's resolution. The video's orientation will match that of the input image.

        It is retained solely for backward compatibility and will be deprecated in the future.
            assets: Provide the assets for image-to-video.
            end_seconds: The total duration of the output video in seconds.
            style: Attributed used to dictate the style of the output
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.image_to_video.create(
            assets={"image_file_path": "api-assets/id/1234.png"},
            end_seconds=5.0,
            style={"prompt": "a dog running"},
            height=960,
            name="Image To Video video",
            width=512,
        )
        ```
        """
        _json = to_encodable(
            item={
                "height": height,
                "name": name,
                "width": width,
                "assets": assets,
                "end_seconds": end_seconds,
                "style": style,
            },
            dump_with=params._SerializerV1ImageToVideoCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/image-to-video",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1ImageToVideoCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing
import typing_extensions


class V1AiHeadshotGeneratorCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1AiHeadshotGeneratorCreateBodyStyle
    """

    prompt: typing_extensions.NotRequired[str]
    """
    A prompt to guide the final image.
    """


class _SerializerV1AiHeadshotGeneratorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiHeadshotGeneratorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    prompt: typing.Optional[str] = pydantic.Field(alias="prompt", default=None)



import pydantic
import typing_extensions


class V1FaceSwapPhotoCreateBodyAssets(typing_extensions.TypedDict):
    """
    Provide the assets for face swap photo
    """

    source_file_path: typing_extensions.Required[str]
    """
    This is the image from which the face is extracted. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """

    target_file_path: typing_extensions.Required[str]
    """
    This is the image where the face from the source image will be placed. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """


class _SerializerV1FaceSwapPhotoCreateBodyAssets(pydantic.BaseModel):
    """
    Serializer for V1FaceSwapPhotoCreateBodyAssets handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    source_file_path: str = pydantic.Field(
        alias="source_file_path",
    )
    target_file_path: str = pydantic.Field(
        alias="target_file_path",
    )



import pydantic
import typing_extensions


class V1PhotoColorizerCreateBodyAssets(typing_extensions.TypedDict):
    """
    Provide the assets for photo colorization
    """

    image_file_path: typing_extensions.Required[str]
    """
    The image used to generate the colorized image. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file.
    """


class _SerializerV1PhotoColorizerCreateBodyAssets(pydantic.BaseModel):
    """
    Serializer for V1PhotoColorizerCreateBodyAssets handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    image_file_path: str = pydantic.Field(
        alias="image_file_path",
    )



from .v1_ai_clothes_changer_create_response import V1AiClothesChangerCreateResponse
from .v1_ai_face_editor_create_response import V1AiFaceEditorCreateResponse
from .v1_ai_gif_generator_create_response import V1AiGifGeneratorCreateResponse
from .v1_ai_headshot_generator_create_response import (
    V1AiHeadshotGeneratorCreateResponse,
)
from .v1_ai_image_generator_create_response import V1AiImageGeneratorCreateResponse
from .v1_ai_image_upscaler_create_response import V1AiImageUpscalerCreateResponse
from .v1_ai_meme_generator_create_response import V1AiMemeGeneratorCreateResponse
from .v1_ai_photo_editor_create_response import V1AiPhotoEditorCreateResponse
from .v1_ai_qr_code_generator_create_response import V1AiQrCodeGeneratorCreateResponse
from .v1_ai_talking_photo_create_response import V1AiTalkingPhotoCreateResponse
from .v1_animation_create_response import V1AnimationCreateResponse
from .v1_face_swap_create_response import V1FaceSwapCreateResponse
from .v1_face_swap_photo_create_response import V1FaceSwapPhotoCreateResponse
from .v1_files_upload_urls_create_response import V1FilesUploadUrlsCreateResponse
from .v1_files_upload_urls_create_response_items_item import (
    V1FilesUploadUrlsCreateResponseItemsItem,
)
from .v1_image_background_remover_create_response import (
    V1ImageBackgroundRemoverCreateResponse,
)
from .v1_image_projects_get_response import V1ImageProjectsGetResponse
from .v1_image_projects_get_response_downloads_item import (
    V1ImageProjectsGetResponseDownloadsItem,
)
from .v1_image_projects_get_response_error import V1ImageProjectsGetResponseError
from .v1_image_to_video_create_response import V1ImageToVideoCreateResponse
from .v1_lip_sync_create_response import V1LipSyncCreateResponse
from .v1_photo_colorizer_create_response import V1PhotoColorizerCreateResponse
from .v1_text_to_video_create_response import V1TextToVideoCreateResponse
from .v1_video_projects_get_response import V1VideoProjectsGetResponse
from .v1_video_projects_get_response_download import V1VideoProjectsGetResponseDownload
from .v1_video_projects_get_response_downloads_item import (
    V1VideoProjectsGetResponseDownloadsItem,
)
from .v1_video_projects_get_response_error import V1VideoProjectsGetResponseError
from .v1_video_to_video_create_response import V1VideoToVideoCreateResponse


__all__ = [
    "V1AiClothesChangerCreateResponse",
    "V1AiFaceEditorCreateResponse",
    "V1AiGifGeneratorCreateResponse",
    "V1AiHeadshotGeneratorCreateResponse",
    "V1AiImageGeneratorCreateResponse",
    "V1AiImageUpscalerCreateResponse",
    "V1AiMemeGeneratorCreateResponse",
    "V1AiPhotoEditorCreateResponse",
    "V1AiQrCodeGeneratorCreateResponse",
    "V1AiTalkingPhotoCreateResponse",
    "V1AnimationCreateResponse",
    "V1FaceSwapCreateResponse",
    "V1FaceSwapPhotoCreateResponse",
    "V1FilesUploadUrlsCreateResponse",
    "V1FilesUploadUrlsCreateResponseItemsItem",
    "V1ImageBackgroundRemoverCreateResponse",
    "V1ImageProjectsGetResponse",
    "V1ImageProjectsGetResponseDownloadsItem",
    "V1ImageProjectsGetResponseError",
    "V1ImageToVideoCreateResponse",
    "V1LipSyncCreateResponse",
    "V1PhotoColorizerCreateResponse",
    "V1TextToVideoCreateResponse",
    "V1VideoProjectsGetResponse",
    "V1VideoProjectsGetResponseDownload",
    "V1VideoProjectsGetResponseDownloadsItem",
    "V1VideoProjectsGetResponseError",
    "V1VideoToVideoCreateResponse",
]



import pydantic


class V1VideoToVideoCreateResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    estimated_frame_cost: int = pydantic.Field(
        alias="estimated_frame_cost",
    )
    """
    Estimated cost of the video in terms of number of frames needed to render the video. Frames will be adjusted when the video completes
    """
    id: str = pydantic.Field(
        alias="id",
    )
    """
    Unique ID of the video. This value can be used in the [get video project API](https://docs.magichour.ai/api-reference/video-projects/get-video-details) to fetch additional details such as status
    """



from typing import (
    Union,
)
from typing_extensions import (
    Literal,
    TypeVar,
    override,
)

_T = TypeVar("_T")


class NotGiven:
    """
    Used to distinguish omitted keyword arguments from those passed explicitly
    with the value None.
    """

    def __bool__(self) -> Literal[False]:
        return False

    @override
    def __repr__(self) -> str:
        return "NOT_GIVEN"


NotGivenOr = Union[_T, NotGiven]
NOT_GIVEN = NotGiven()



import pydantic
import typing
import typing_extensions

from .v1_ai_gif_generator_create_body_style import (
    V1AiGifGeneratorCreateBodyStyle,
    _SerializerV1AiGifGeneratorCreateBodyStyle,
)


class V1AiGifGeneratorCreateBody(typing_extensions.TypedDict):
    """
    V1AiGifGeneratorCreateBody
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of gif
    """

    style: typing_extensions.Required[V1AiGifGeneratorCreateBodyStyle]


class _SerializerV1AiGifGeneratorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiGifGeneratorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    style: _SerializerV1AiGifGeneratorCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic
import typing
import typing_extensions

from .v1_files_upload_urls_create_body_items_item import (
    V1FilesUploadUrlsCreateBodyItemsItem,
    _SerializerV1FilesUploadUrlsCreateBodyItemsItem,
)


class V1FilesUploadUrlsCreateBody(typing_extensions.TypedDict):
    """
    V1FilesUploadUrlsCreateBody
    """

    items: typing_extensions.Required[typing.List[V1FilesUploadUrlsCreateBodyItemsItem]]


class _SerializerV1FilesUploadUrlsCreateBody(pydantic.BaseModel):
    """
    Serializer for V1FilesUploadUrlsCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    items: typing.List[_SerializerV1FilesUploadUrlsCreateBodyItemsItem] = (
        pydantic.Field(
            alias="items",
        )
    )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiMemeGeneratorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        style: params.V1AiMemeGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiMemeGeneratorCreateResponse:
        """
        AI Meme Generator

        Create an AI generated meme. Each meme costs 10 frames.

        POST /v1/ai-meme-generator

        Args:
            name: The name of the meme.
            style: V1AiMemeGeneratorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_meme_generator.create(
            style={
                "search_web": False,
                "template": "Drake Hotline Bling",
                "topic": "When the code finally works",
            },
            name="My Funny Meme",
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "style": style},
            dump_with=params._SerializerV1AiMemeGeneratorCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-meme-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiMemeGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiMemeGeneratorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        style: params.V1AiMemeGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiMemeGeneratorCreateResponse:
        """
        AI Meme Generator

        Create an AI generated meme. Each meme costs 10 frames.

        POST /v1/ai-meme-generator

        Args:
            name: The name of the meme.
            style: V1AiMemeGeneratorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_meme_generator.create(
            style={
                "search_web": False,
                "template": "Drake Hotline Bling",
                "topic": "When the code finally works",
            },
            name="My Funny Meme",
        )
        ```
        """
        _json = to_encodable(
            item={"name": name, "style": style},
            dump_with=params._SerializerV1AiMemeGeneratorCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-meme-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiMemeGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing
import typing_extensions


class V1AiMemeGeneratorCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1AiMemeGeneratorCreateBodyStyle
    """

    search_web: typing_extensions.NotRequired[bool]
    """
    Whether to search the web for meme content.
    """

    template: typing_extensions.Required[
        typing_extensions.Literal[
            "Bike Fall",
            "Change My Mind",
            "Disappointed Guy",
            "Drake Hotline Bling",
            "Galaxy Brain",
            "Gru's Plan",
            "Is This a Pigeon",
            "Panik Kalm Panik",
            "Random",
            "Side Eyeing Chloe",
            "Tuxedo Winnie The Pooh",
            "Two Buttons",
            "Waiting Skeleton",
        ]
    ]
    """
    To use our templates, pass in one of the enum values.
    """

    topic: typing_extensions.Required[str]
    """
    The topic of the meme.
    """


class _SerializerV1AiMemeGeneratorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiMemeGeneratorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    search_web: typing.Optional[bool] = pydantic.Field(alias="searchWeb", default=None)
    template: typing_extensions.Literal[
        "Bike Fall",
        "Change My Mind",
        "Disappointed Guy",
        "Drake Hotline Bling",
        "Galaxy Brain",
        "Gru's Plan",
        "Is This a Pigeon",
        "Panik Kalm Panik",
        "Random",
        "Side Eyeing Chloe",
        "Tuxedo Winnie The Pooh",
        "Two Buttons",
        "Waiting Skeleton",
    ] = pydantic.Field(
        alias="template",
    )
    topic: str = pydantic.Field(
        alias="topic",
    )



from magic_hour.core import AsyncBaseClient, SyncBaseClient
from magic_hour.resources.v1.ai_clothes_changer import (
    AiClothesChangerClient,
    AsyncAiClothesChangerClient,
)
from magic_hour.resources.v1.ai_face_editor import (
    AiFaceEditorClient,
    AsyncAiFaceEditorClient,
)
from magic_hour.resources.v1.ai_gif_generator import (
    AiGifGeneratorClient,
    AsyncAiGifGeneratorClient,
)
from magic_hour.resources.v1.ai_headshot_generator import (
    AiHeadshotGeneratorClient,
    AsyncAiHeadshotGeneratorClient,
)
from magic_hour.resources.v1.ai_image_generator import (
    AiImageGeneratorClient,
    AsyncAiImageGeneratorClient,
)
from magic_hour.resources.v1.ai_image_upscaler import (
    AiImageUpscalerClient,
    AsyncAiImageUpscalerClient,
)
from magic_hour.resources.v1.ai_meme_generator import (
    AiMemeGeneratorClient,
    AsyncAiMemeGeneratorClient,
)
from magic_hour.resources.v1.ai_photo_editor import (
    AiPhotoEditorClient,
    AsyncAiPhotoEditorClient,
)
from magic_hour.resources.v1.ai_qr_code_generator import (
    AiQrCodeGeneratorClient,
    AsyncAiQrCodeGeneratorClient,
)
from magic_hour.resources.v1.ai_talking_photo import (
    AiTalkingPhotoClient,
    AsyncAiTalkingPhotoClient,
)
from magic_hour.resources.v1.animation import AnimationClient, AsyncAnimationClient
from magic_hour.resources.v1.face_swap import AsyncFaceSwapClient, FaceSwapClient
from magic_hour.resources.v1.face_swap_photo import (
    AsyncFaceSwapPhotoClient,
    FaceSwapPhotoClient,
)
from magic_hour.resources.v1.files import AsyncFilesClient, FilesClient
from magic_hour.resources.v1.image_background_remover import (
    AsyncImageBackgroundRemoverClient,
    ImageBackgroundRemoverClient,
)
from magic_hour.resources.v1.image_projects import (
    AsyncImageProjectsClient,
    ImageProjectsClient,
)
from magic_hour.resources.v1.image_to_video import (
    AsyncImageToVideoClient,
    ImageToVideoClient,
)
from magic_hour.resources.v1.lip_sync import AsyncLipSyncClient, LipSyncClient
from magic_hour.resources.v1.photo_colorizer import (
    AsyncPhotoColorizerClient,
    PhotoColorizerClient,
)
from magic_hour.resources.v1.text_to_video import (
    AsyncTextToVideoClient,
    TextToVideoClient,
)
from magic_hour.resources.v1.video_projects import (
    AsyncVideoProjectsClient,
    VideoProjectsClient,
)
from magic_hour.resources.v1.video_to_video import (
    AsyncVideoToVideoClient,
    VideoToVideoClient,
)


class V1Client:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client
        self.image_projects = ImageProjectsClient(base_client=self._base_client)
        self.video_projects = VideoProjectsClient(base_client=self._base_client)
        self.ai_clothes_changer = AiClothesChangerClient(base_client=self._base_client)
        self.ai_face_editor = AiFaceEditorClient(base_client=self._base_client)
        self.ai_gif_generator = AiGifGeneratorClient(base_client=self._base_client)
        self.ai_headshot_generator = AiHeadshotGeneratorClient(
            base_client=self._base_client
        )
        self.ai_image_generator = AiImageGeneratorClient(base_client=self._base_client)
        self.ai_image_upscaler = AiImageUpscalerClient(base_client=self._base_client)
        self.ai_meme_generator = AiMemeGeneratorClient(base_client=self._base_client)
        self.ai_photo_editor = AiPhotoEditorClient(base_client=self._base_client)
        self.ai_qr_code_generator = AiQrCodeGeneratorClient(
            base_client=self._base_client
        )
        self.ai_talking_photo = AiTalkingPhotoClient(base_client=self._base_client)
        self.animation = AnimationClient(base_client=self._base_client)
        self.face_swap = FaceSwapClient(base_client=self._base_client)
        self.face_swap_photo = FaceSwapPhotoClient(base_client=self._base_client)
        self.files = FilesClient(base_client=self._base_client)
        self.image_background_remover = ImageBackgroundRemoverClient(
            base_client=self._base_client
        )
        self.image_to_video = ImageToVideoClient(base_client=self._base_client)
        self.lip_sync = LipSyncClient(base_client=self._base_client)
        self.photo_colorizer = PhotoColorizerClient(base_client=self._base_client)
        self.text_to_video = TextToVideoClient(base_client=self._base_client)
        self.video_to_video = VideoToVideoClient(base_client=self._base_client)


class AsyncV1Client:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client
        self.image_projects = AsyncImageProjectsClient(base_client=self._base_client)
        self.video_projects = AsyncVideoProjectsClient(base_client=self._base_client)
        self.ai_clothes_changer = AsyncAiClothesChangerClient(
            base_client=self._base_client
        )
        self.ai_face_editor = AsyncAiFaceEditorClient(base_client=self._base_client)
        self.ai_gif_generator = AsyncAiGifGeneratorClient(base_client=self._base_client)
        self.ai_headshot_generator = AsyncAiHeadshotGeneratorClient(
            base_client=self._base_client
        )
        self.ai_image_generator = AsyncAiImageGeneratorClient(
            base_client=self._base_client
        )
        self.ai_image_upscaler = AsyncAiImageUpscalerClient(
            base_client=self._base_client
        )
        self.ai_meme_generator = AsyncAiMemeGeneratorClient(
            base_client=self._base_client
        )
        self.ai_photo_editor = AsyncAiPhotoEditorClient(base_client=self._base_client)
        self.ai_qr_code_generator = AsyncAiQrCodeGeneratorClient(
            base_client=self._base_client
        )
        self.ai_talking_photo = AsyncAiTalkingPhotoClient(base_client=self._base_client)
        self.animation = AsyncAnimationClient(base_client=self._base_client)
        self.face_swap = AsyncFaceSwapClient(base_client=self._base_client)
        self.face_swap_photo = AsyncFaceSwapPhotoClient(base_client=self._base_client)
        self.files = AsyncFilesClient(base_client=self._base_client)
        self.image_background_remover = AsyncImageBackgroundRemoverClient(
            base_client=self._base_client
        )
        self.image_to_video = AsyncImageToVideoClient(base_client=self._base_client)
        self.lip_sync = AsyncLipSyncClient(base_client=self._base_client)
        self.photo_colorizer = AsyncPhotoColorizerClient(base_client=self._base_client)
        self.text_to_video = AsyncTextToVideoClient(base_client=self._base_client)
        self.video_to_video = AsyncVideoToVideoClient(base_client=self._base_client)



import pydantic
import typing
import typing_extensions

from .v1_ai_talking_photo_create_body_assets import (
    V1AiTalkingPhotoCreateBodyAssets,
    _SerializerV1AiTalkingPhotoCreateBodyAssets,
)


class V1AiTalkingPhotoCreateBody(typing_extensions.TypedDict):
    """
    Provide the assets for creating a talking photo
    """

    assets: typing_extensions.Required[V1AiTalkingPhotoCreateBodyAssets]
    """
    Provide the assets for creating a talking photo
    """

    end_seconds: typing_extensions.Required[float]
    """
    The end time of the input video in seconds
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    start_seconds: typing_extensions.Required[float]
    """
    The start time of the input video in seconds
    """


class _SerializerV1AiTalkingPhotoCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiTalkingPhotoCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AiTalkingPhotoCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    start_seconds: float = pydantic.Field(
        alias="start_seconds",
    )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class LipSyncClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1LipSyncCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        height: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        max_fps_limit: typing.Union[
            typing.Optional[float], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        width: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1LipSyncCreateResponse:
        """
        Lip Sync

        Create a Lip Sync video. The estimated frame cost is calculated using 30 FPS. This amount is deducted from your account balance when a video is queued. Once the video is complete, the cost will be updated based on the actual number of frames rendered.

        Get more information about this mode at our [product page](/products/lip-sync).


        POST /v1/lip-sync

        Args:
            height: Used to determine the dimensions of the output video.

        * If height is provided, width will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            max_fps_limit: Defines the maximum FPS (frames per second) for the output video. If the input video's FPS is lower than this limit, the output video will retain the input FPS. This is useful for reducing unnecessary frame usage in scenarios where high FPS is not required.
            name: The name of video
            width: Used to determine the dimensions of the output video.

        * If width is provided, height will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            assets: Provide the assets for lip-sync. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
            end_seconds: The end time of the input video in seconds
            start_seconds: The start time of the input video in seconds
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.lip_sync.create(
            assets={
                "audio_file_path": "api-assets/id/1234.mp3",
                "video_file_path": "api-assets/id/1234.mp4",
                "video_source": "file",
            },
            end_seconds=15.0,
            start_seconds=0.0,
            height=960,
            max_fps_limit=12.0,
            name="Lip Sync video",
            width=512,
        )
        ```
        """
        _json = to_encodable(
            item={
                "height": height,
                "max_fps_limit": max_fps_limit,
                "name": name,
                "width": width,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
            },
            dump_with=params._SerializerV1LipSyncCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/lip-sync",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1LipSyncCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncLipSyncClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1LipSyncCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        height: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        max_fps_limit: typing.Union[
            typing.Optional[float], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        width: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1LipSyncCreateResponse:
        """
        Lip Sync

        Create a Lip Sync video. The estimated frame cost is calculated using 30 FPS. This amount is deducted from your account balance when a video is queued. Once the video is complete, the cost will be updated based on the actual number of frames rendered.

        Get more information about this mode at our [product page](/products/lip-sync).


        POST /v1/lip-sync

        Args:
            height: Used to determine the dimensions of the output video.

        * If height is provided, width will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            max_fps_limit: Defines the maximum FPS (frames per second) for the output video. If the input video's FPS is lower than this limit, the output video will retain the input FPS. This is useful for reducing unnecessary frame usage in scenarios where high FPS is not required.
            name: The name of video
            width: Used to determine the dimensions of the output video.

        * If width is provided, height will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            assets: Provide the assets for lip-sync. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
            end_seconds: The end time of the input video in seconds
            start_seconds: The start time of the input video in seconds
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.lip_sync.create(
            assets={
                "audio_file_path": "api-assets/id/1234.mp3",
                "video_file_path": "api-assets/id/1234.mp4",
                "video_source": "file",
            },
            end_seconds=15.0,
            start_seconds=0.0,
            height=960,
            max_fps_limit=12.0,
            name="Lip Sync video",
            width=512,
        )
        ```
        """
        _json = to_encodable(
            item={
                "height": height,
                "max_fps_limit": max_fps_limit,
                "name": name,
                "width": width,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
            },
            dump_with=params._SerializerV1LipSyncCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/lip-sync",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1LipSyncCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing_extensions


class V1AiFaceEditorCreateBodyStyle(typing_extensions.TypedDict):
    """
    Face editing parameters
    """

    enhance_face: typing_extensions.Required[bool]
    """
    Enhance face features
    """

    eye_gaze_horizontal: typing_extensions.Required[float]
    """
    Horizontal eye gaze (-100 to 100), in increments of 5
    """

    eye_gaze_vertical: typing_extensions.Required[float]
    """
    Vertical eye gaze (-100 to 100), in increments of 5
    """

    eye_open_ratio: typing_extensions.Required[float]
    """
    Eye open ratio (-100 to 100), in increments of 5
    """

    eyebrow_direction: typing_extensions.Required[float]
    """
    Eyebrow direction (-100 to 100), in increments of 5
    """

    head_pitch: typing_extensions.Required[float]
    """
    Head pitch (-100 to 100), in increments of 5
    """

    head_roll: typing_extensions.Required[float]
    """
    Head roll (-100 to 100), in increments of 5
    """

    head_yaw: typing_extensions.Required[float]
    """
    Head yaw (-100 to 100), in increments of 5
    """

    lip_open_ratio: typing_extensions.Required[float]
    """
    Lip open ratio (-100 to 100), in increments of 5
    """

    mouth_grim: typing_extensions.Required[float]
    """
    Mouth grim (-100 to 100), in increments of 5
    """

    mouth_position_horizontal: typing_extensions.Required[float]
    """
    Horizontal mouth position (-100 to 100), in increments of 5
    """

    mouth_position_vertical: typing_extensions.Required[float]
    """
    Vertical mouth position (-100 to 100), in increments of 5
    """

    mouth_pout: typing_extensions.Required[float]
    """
    Mouth pout (-100 to 100), in increments of 5
    """

    mouth_purse: typing_extensions.Required[float]
    """
    Mouth purse (-100 to 100), in increments of 5
    """

    mouth_smile: typing_extensions.Required[float]
    """
    Mouth smile (-100 to 100), in increments of 5
    """


class _SerializerV1AiFaceEditorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiFaceEditorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    enhance_face: bool = pydantic.Field(
        alias="enhance_face",
    )
    eye_gaze_horizontal: float = pydantic.Field(
        alias="eye_gaze_horizontal",
    )
    eye_gaze_vertical: float = pydantic.Field(
        alias="eye_gaze_vertical",
    )
    eye_open_ratio: float = pydantic.Field(
        alias="eye_open_ratio",
    )
    eyebrow_direction: float = pydantic.Field(
        alias="eyebrow_direction",
    )
    head_pitch: float = pydantic.Field(
        alias="head_pitch",
    )
    head_roll: float = pydantic.Field(
        alias="head_roll",
    )
    head_yaw: float = pydantic.Field(
        alias="head_yaw",
    )
    lip_open_ratio: float = pydantic.Field(
        alias="lip_open_ratio",
    )
    mouth_grim: float = pydantic.Field(
        alias="mouth_grim",
    )
    mouth_position_horizontal: float = pydantic.Field(
        alias="mouth_position_horizontal",
    )
    mouth_position_vertical: float = pydantic.Field(
        alias="mouth_position_vertical",
    )
    mouth_pout: float = pydantic.Field(
        alias="mouth_pout",
    )
    mouth_purse: float = pydantic.Field(
        alias="mouth_purse",
    )
    mouth_smile: float = pydantic.Field(
        alias="mouth_smile",
    )



import pydantic
import typing
import typing_extensions

from .v1_lip_sync_create_body_assets import (
    V1LipSyncCreateBodyAssets,
    _SerializerV1LipSyncCreateBodyAssets,
)


class V1LipSyncCreateBody(typing_extensions.TypedDict):
    """
    V1LipSyncCreateBody
    """

    assets: typing_extensions.Required[V1LipSyncCreateBodyAssets]
    """
    Provide the assets for lip-sync. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
    """

    end_seconds: typing_extensions.Required[float]
    """
    The end time of the input video in seconds
    """

    height: typing_extensions.NotRequired[int]
    """
    Used to determine the dimensions of the output video. 
      
    * If height is provided, width will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
    * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.
    
    Note: if the video's original resolution is less than the maximum, the video will not be resized.
    
    See our [pricing page](https://magichour.ai/pricing) for more details.
    """

    max_fps_limit: typing_extensions.NotRequired[float]
    """
    Defines the maximum FPS (frames per second) for the output video. If the input video's FPS is lower than this limit, the output video will retain the input FPS. This is useful for reducing unnecessary frame usage in scenarios where high FPS is not required.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    start_seconds: typing_extensions.Required[float]
    """
    The start time of the input video in seconds
    """

    width: typing_extensions.NotRequired[int]
    """
    Used to determine the dimensions of the output video. 
      
    * If width is provided, height will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
    * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.
    
    Note: if the video's original resolution is less than the maximum, the video will not be resized.
    
    See our [pricing page](https://magichour.ai/pricing) for more details.
    """


class _SerializerV1LipSyncCreateBody(pydantic.BaseModel):
    """
    Serializer for V1LipSyncCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1LipSyncCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    height: typing.Optional[int] = pydantic.Field(alias="height", default=None)
    max_fps_limit: typing.Optional[float] = pydantic.Field(
        alias="max_fps_limit", default=None
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    start_seconds: float = pydantic.Field(
        alias="start_seconds",
    )
    width: typing.Optional[int] = pydantic.Field(alias="width", default=None)



import json

from typing import Any, Dict, Union
from typing_extensions import Literal, Sequence
from urllib.parse import quote_plus, quote

import httpx


# Type alias for query parameters that can handle both primitive data and sequences
QueryParams = Dict[
    str, Union[httpx._types.PrimitiveData, Sequence[httpx._types.PrimitiveData]]
]
QueryParamStyle = Literal["form", "spaceDelimited", "pipeDelimited", "deepObject"]


def encode_query_param(
    params: QueryParams,
    name: str,
    value: Any,
    style: QueryParamStyle = "form",
    explode: bool = True,
):
    if style == "form":
        _encode_form(params, name, value, explode)
    elif style == "spaceDelimited":
        _encode_spaced_delimited(params, name, value, explode)
    elif style == "pipeDelimited":
        _encode_pipe_delimited(params, name, value, explode)
    elif style == "deepObject":
        _encode_deep_object(params, name, value, explode)
    else:
        raise NotImplementedError(f"query param style '{style}' not implemented")


def _query_str(val: Any) -> str:
    """jsonify value without wrapping quotes for strings"""
    if isinstance(val, str):
        return val
    return json.dumps(val)


def _encode_form(params: QueryParams, name: str, value: Any, explode: bool):
    """
    Encodes query params in the `form` style as defined by OpenAPI with both explode and non-explode
    variants.
    """
    if isinstance(value, list) and not explode:
        # non-explode form lists should be encoded like /users?id=3,4,5
        params[name] = quote_plus(",".join(map(_query_str, value)))
    elif isinstance(value, dict):
        if explode:
            # explode form objects should be encoded like /users?key0=val0&key1=val1
            # the input param name will be omitted
            for k, v in value.items():
                params[k] = quote_plus(_query_str(v))
        else:
            # non-explode form objects should be encoded like /users?id=key0,val0,key1,val1
            encoded_chunks = []
            for k, v in value.items():
                encoded_chunks.extend([str(k), _query_str(v)])
            params[name] = quote_plus(",".join(encoded_chunks))
    else:
        params[name] = value


def _encode_spaced_delimited(params: QueryParams, name: str, value: Any, explode: bool):
    """
    Encodes query params in the `spaceDelimited` style as defined by OpenAPI with both explode and non-explode
    variants.
    """
    if isinstance(value, list) and not explode:
        # non-explode spaceDelimited lists should be encoded like /users?id=3%204%205
        params[name] = quote(" ".join(map(_query_str, value)))
    else:
        # according to the docs, spaceDelimited + explode=false only effects lists,
        # all other encodings are marked as n/a or are the same as `form` style
        # fall back on form style as it is the default for query params
        _encode_form(params, name, value, explode)


def _encode_pipe_delimited(params: QueryParams, name: str, value: Any, explode: bool):
    """
    Encodes query params in the `pipeDelimited` style as defined by OpenAPI with both explode and non-explode
    variants.
    """
    if isinstance(value, list) and not explode:
        # non-explode pipeDelimited lists should be encoded like /users?id=3|4|5
        params[name] = quote("|".join(map(_query_str, value)))
    else:
        # according to the docs, pipeDelimited + explode=false only effects lists,
        # all other encodings are marked as n/a or are the same as `form` style
        # fall back on form style as it is the default for query params
        _encode_form(params, name, value, explode)


def _encode_deep_object(params: QueryParams, name: str, value: Any, explode: bool):
    """
    Encodes query params in the `deepObject` style as defined by with both explode and non-explode
    variants.
    """
    if isinstance(value, (dict, list)):
        _encode_deep_object_key(params, name, value)
    else:
        # according to the docs, deepObject style only applies to
        # object encodes, encodings for primitives are listed as n/a,
        # fall back on form style as it is the default for query params
        _encode_form(params, name, value, explode)


def _encode_deep_object_key(params: QueryParams, key: str, value: Any):
    if isinstance(value, dict):
        for k, v in value.items():
            _encode_deep_object_key(params, f"{key}[{k}]", v)
    elif isinstance(value, list):
        for i, v in enumerate(value):
            _encode_deep_object_key(params, f"{key}[{i}]", v)
    else:
        params[key] = _query_str(value)



import pydantic
import typing
import typing_extensions

from .v1_ai_photo_editor_create_body_assets import (
    V1AiPhotoEditorCreateBodyAssets,
    _SerializerV1AiPhotoEditorCreateBodyAssets,
)
from .v1_ai_photo_editor_create_body_style import (
    V1AiPhotoEditorCreateBodyStyle,
    _SerializerV1AiPhotoEditorCreateBodyStyle,
)


class V1AiPhotoEditorCreateBody(typing_extensions.TypedDict):
    """
    V1AiPhotoEditorCreateBody
    """

    assets: typing_extensions.Required[V1AiPhotoEditorCreateBodyAssets]
    """
    Provide the assets for photo editor
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    resolution: typing_extensions.Required[int]
    """
    The resolution of the final output image. The allowed value is based on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
    """

    steps: typing_extensions.NotRequired[int]
    """
    Deprecated: Please use `.style.steps` instead. Number of iterations used to generate the output. Higher values improve quality and increase the strength of the prompt but increase processing time.
    """

    style: typing_extensions.Required[V1AiPhotoEditorCreateBodyStyle]


class _SerializerV1AiPhotoEditorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiPhotoEditorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AiPhotoEditorCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    resolution: int = pydantic.Field(
        alias="resolution",
    )
    steps: typing.Optional[int] = pydantic.Field(alias="steps", default=None)
    style: _SerializerV1AiPhotoEditorCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic
import typing
import typing_extensions

from .v1_face_swap_create_body_assets import (
    V1FaceSwapCreateBodyAssets,
    _SerializerV1FaceSwapCreateBodyAssets,
)


class V1FaceSwapCreateBody(typing_extensions.TypedDict):
    """
    V1FaceSwapCreateBody
    """

    assets: typing_extensions.Required[V1FaceSwapCreateBodyAssets]
    """
    Provide the assets for face swap. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
    """

    end_seconds: typing_extensions.Required[float]
    """
    The end time of the input video in seconds
    """

    height: typing_extensions.NotRequired[int]
    """
    Used to determine the dimensions of the output video. 
      
    * If height is provided, width will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
    * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.
    
    Note: if the video's original resolution is less than the maximum, the video will not be resized.
    
    See our [pricing page](https://magichour.ai/pricing) for more details.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    start_seconds: typing_extensions.Required[float]
    """
    The start time of the input video in seconds
    """

    width: typing_extensions.NotRequired[int]
    """
    Used to determine the dimensions of the output video. 
      
    * If width is provided, height will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
    * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.
    
    Note: if the video's original resolution is less than the maximum, the video will not be resized.
    
    See our [pricing page](https://magichour.ai/pricing) for more details.
    """


class _SerializerV1FaceSwapCreateBody(pydantic.BaseModel):
    """
    Serializer for V1FaceSwapCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1FaceSwapCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    height: typing.Optional[int] = pydantic.Field(alias="height", default=None)
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    start_seconds: float = pydantic.Field(
        alias="start_seconds",
    )
    width: typing.Optional[int] = pydantic.Field(alias="width", default=None)



import typing
import typing_extensions

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class VideoToVideoClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1VideoToVideoCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        style: params.V1VideoToVideoCreateBodyStyle,
        fps_resolution: typing.Union[
            typing.Optional[typing_extensions.Literal["FULL", "HALF"]],
            type_utils.NotGiven,
        ] = type_utils.NOT_GIVEN,
        height: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        width: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1VideoToVideoCreateResponse:
        """
        Video-to-Video

        Create a Video To Video video. The estimated frame cost is calculated using 30 FPS. This amount is deducted from your account balance when a video is queued. Once the video is complete, the cost will be updated based on the actual number of frames rendered.

        Get more information about this mode at our [product page](/products/video-to-video).


        POST /v1/video-to-video

        Args:
            fps_resolution: Determines whether the resulting video will have the same frame per second as the original video, or half.
        * `FULL` - the result video will have the same FPS as the input video
        * `HALF` - the result video will have half the FPS as the input video
            height: Used to determine the dimensions of the output video.

        * If height is provided, width will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            name: The name of video
            width: Used to determine the dimensions of the output video.

        * If width is provided, height will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            assets: Provide the assets for video-to-video. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
            end_seconds: The end time of the input video in seconds
            start_seconds: The start time of the input video in seconds
            style: V1VideoToVideoCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.video_to_video.create(
            assets={
                "video_file_path": "api-assets/id/1234.mp4",
                "video_source": "file",
            },
            end_seconds=15.0,
            start_seconds=0.0,
            style={
                "art_style": "3D Render",
                "model": "Absolute Reality",
                "prompt": "string",
                "prompt_type": "append_default",
                "version": "default",
            },
            fps_resolution="HALF",
            height=960,
            name="Video To Video video",
            width=512,
        )
        ```
        """
        _json = to_encodable(
            item={
                "fps_resolution": fps_resolution,
                "height": height,
                "name": name,
                "width": width,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
                "style": style,
            },
            dump_with=params._SerializerV1VideoToVideoCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/video-to-video",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1VideoToVideoCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncVideoToVideoClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1VideoToVideoCreateBodyAssets,
        end_seconds: float,
        start_seconds: float,
        style: params.V1VideoToVideoCreateBodyStyle,
        fps_resolution: typing.Union[
            typing.Optional[typing_extensions.Literal["FULL", "HALF"]],
            type_utils.NotGiven,
        ] = type_utils.NOT_GIVEN,
        height: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        width: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1VideoToVideoCreateResponse:
        """
        Video-to-Video

        Create a Video To Video video. The estimated frame cost is calculated using 30 FPS. This amount is deducted from your account balance when a video is queued. Once the video is complete, the cost will be updated based on the actual number of frames rendered.

        Get more information about this mode at our [product page](/products/video-to-video).


        POST /v1/video-to-video

        Args:
            fps_resolution: Determines whether the resulting video will have the same frame per second as the original video, or half.
        * `FULL` - the result video will have the same FPS as the input video
        * `HALF` - the result video will have half the FPS as the input video
            height: Used to determine the dimensions of the output video.

        * If height is provided, width will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            name: The name of video
            width: Used to determine the dimensions of the output video.

        * If width is provided, height will also be required. The larger value between width and height will be used to determine the maximum output resolution while maintaining the original aspect ratio.
        * If both height and width are omitted, the video will be resized according to your subscription's maximum resolution, while preserving aspect ratio.

        Note: if the video's original resolution is less than the maximum, the video will not be resized.

        See our [pricing page](https://magichour.ai/pricing) for more details.
            assets: Provide the assets for video-to-video. For video, The `video_source` field determines whether `video_file_path` or `youtube_url` field is used
            end_seconds: The end time of the input video in seconds
            start_seconds: The start time of the input video in seconds
            style: V1VideoToVideoCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.video_to_video.create(
            assets={
                "video_file_path": "api-assets/id/1234.mp4",
                "video_source": "file",
            },
            end_seconds=15.0,
            start_seconds=0.0,
            style={
                "art_style": "3D Render",
                "model": "Absolute Reality",
                "prompt": "string",
                "prompt_type": "append_default",
                "version": "default",
            },
            fps_resolution="HALF",
            height=960,
            name="Video To Video video",
            width=512,
        )
        ```
        """
        _json = to_encodable(
            item={
                "fps_resolution": fps_resolution,
                "height": height,
                "name": name,
                "width": width,
                "assets": assets,
                "end_seconds": end_seconds,
                "start_seconds": start_seconds,
                "style": style,
            },
            dump_with=params._SerializerV1VideoToVideoCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/video-to-video",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1VideoToVideoCreateResponse,
            request_options=request_options or default_request_options(),
        )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
)
from magic_hour.types import models


class ImageProjectsClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def delete(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete image

        Permanently delete the rendered image. This action is not reversible, please be sure before deleting.

        DELETE /v1/image-projects/{id}

        Args:
            id: The id of the image project
            request_options: Additional options to customize the HTTP request

        Returns:
            204

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.image_projects.delete(id="cm6pvghix03bvyz0zwash6noj")
        ```
        """
        self._base_client.request(
            method="DELETE",
            path=f"/v1/image-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=type(None),
            request_options=request_options or default_request_options(),
        )

    def get(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> models.V1ImageProjectsGetResponse:
        """
        Get image details

        Get the details of a image project. The `downloads` field will be empty unless the image was successfully rendered.

        The image can be one of the following status
        - `draft` - not currently used
        - `queued` - the job is queued and waiting for a GPU
        - `rendering` - the generation is in progress
        - `complete` - the image is successful created
        - `error` - an error occurred during rendering
        - `canceled` - image render is canceled by the user


        GET /v1/image-projects/{id}

        Args:
            id: The id of the image project
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.image_projects.get(id="cm6pvghix03bvyz0zwash6noj")
        ```
        """
        return self._base_client.request(
            method="GET",
            path=f"/v1/image-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=models.V1ImageProjectsGetResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncImageProjectsClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def delete(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete image

        Permanently delete the rendered image. This action is not reversible, please be sure before deleting.

        DELETE /v1/image-projects/{id}

        Args:
            id: The id of the image project
            request_options: Additional options to customize the HTTP request

        Returns:
            204

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.image_projects.delete(id="cm6pvghix03bvyz0zwash6noj")
        ```
        """
        await self._base_client.request(
            method="DELETE",
            path=f"/v1/image-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=type(None),
            request_options=request_options or default_request_options(),
        )

    async def get(
        self, *, id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> models.V1ImageProjectsGetResponse:
        """
        Get image details

        Get the details of a image project. The `downloads` field will be empty unless the image was successfully rendered.

        The image can be one of the following status
        - `draft` - not currently used
        - `queued` - the job is queued and waiting for a GPU
        - `rendering` - the generation is in progress
        - `complete` - the image is successful created
        - `error` - an error occurred during rendering
        - `canceled` - image render is canceled by the user


        GET /v1/image-projects/{id}

        Args:
            id: The id of the image project
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.image_projects.get(id="cm6pvghix03bvyz0zwash6noj")
        ```
        """
        return await self._base_client.request(
            method="GET",
            path=f"/v1/image-projects/{id}",
            auth_names=["bearerAuth"],
            cast_to=models.V1ImageProjectsGetResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing

from .v1_files_upload_urls_create_response_items_item import (
    V1FilesUploadUrlsCreateResponseItemsItem,
)


class V1FilesUploadUrlsCreateResponse(pydantic.BaseModel):
    """
    Success
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    items: typing.List[V1FilesUploadUrlsCreateResponseItemsItem] = pydantic.Field(
        alias="items",
    )



import pydantic
import typing
import typing_extensions

from .v1_animation_create_body_assets import (
    V1AnimationCreateBodyAssets,
    _SerializerV1AnimationCreateBodyAssets,
)
from .v1_animation_create_body_style import (
    V1AnimationCreateBodyStyle,
    _SerializerV1AnimationCreateBodyStyle,
)


class V1AnimationCreateBody(typing_extensions.TypedDict):
    """
    V1AnimationCreateBody
    """

    assets: typing_extensions.Required[V1AnimationCreateBodyAssets]
    """
    Provide the assets for animation.
    """

    end_seconds: typing_extensions.Required[float]
    """
    The end time of the input video in seconds
    """

    fps: typing_extensions.Required[float]
    """
    The desire output video frame rate
    """

    height: typing_extensions.Required[int]
    """
    The height of the final output video. The maximum height depends on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of video
    """

    style: typing_extensions.Required[V1AnimationCreateBodyStyle]
    """
    Defines the style of the output video
    """

    width: typing_extensions.Required[int]
    """
    The width of the final output video. The maximum width depends on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
    """


class _SerializerV1AnimationCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AnimationCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AnimationCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    end_seconds: float = pydantic.Field(
        alias="end_seconds",
    )
    fps: float = pydantic.Field(
        alias="fps",
    )
    height: int = pydantic.Field(
        alias="height",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    style: _SerializerV1AnimationCreateBodyStyle = pydantic.Field(
        alias="style",
    )
    width: int = pydantic.Field(
        alias="width",
    )



import pydantic
import typing
import typing_extensions

from .v1_ai_qr_code_generator_create_body_style import (
    V1AiQrCodeGeneratorCreateBodyStyle,
    _SerializerV1AiQrCodeGeneratorCreateBodyStyle,
)


class V1AiQrCodeGeneratorCreateBody(typing_extensions.TypedDict):
    """
    V1AiQrCodeGeneratorCreateBody
    """

    content: typing_extensions.Required[str]
    """
    The content of the QR code.
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    style: typing_extensions.Required[V1AiQrCodeGeneratorCreateBodyStyle]


class _SerializerV1AiQrCodeGeneratorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiQrCodeGeneratorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    content: str = pydantic.Field(
        alias="content",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    style: _SerializerV1AiQrCodeGeneratorCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic
import typing
import typing_extensions

from .v1_ai_face_editor_create_body_assets import (
    V1AiFaceEditorCreateBodyAssets,
    _SerializerV1AiFaceEditorCreateBodyAssets,
)
from .v1_ai_face_editor_create_body_style import (
    V1AiFaceEditorCreateBodyStyle,
    _SerializerV1AiFaceEditorCreateBodyStyle,
)


class V1AiFaceEditorCreateBody(typing_extensions.TypedDict):
    """
    V1AiFaceEditorCreateBody
    """

    assets: typing_extensions.Required[V1AiFaceEditorCreateBodyAssets]
    """
    Provide the assets for face editor
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    style: typing_extensions.Required[V1AiFaceEditorCreateBodyStyle]
    """
    Face editing parameters
    """


class _SerializerV1AiFaceEditorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiFaceEditorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    assets: _SerializerV1AiFaceEditorCreateBodyAssets = pydantic.Field(
        alias="assets",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    style: _SerializerV1AiFaceEditorCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic


class V1VideoProjectsGetResponseDownloadsItem(pydantic.BaseModel):
    """
    The download url and expiration date of the image project
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    expires_at: str = pydantic.Field(
        alias="expires_at",
    )
    url: str = pydantic.Field(
        alias="url",
    )



import typing

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiPhotoEditorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        assets: params.V1AiPhotoEditorCreateBodyAssets,
        resolution: int,
        style: params.V1AiPhotoEditorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        steps: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiPhotoEditorCreateResponse:
        """
        AI Photo Editor

        > **NOTE**: this API is still in early development stages, and should be avoided. Please reach out to us if you're interested in this API.

        Edit photo using AI. Each photo costs 10 frames.

        POST /v1/ai-photo-editor

        Args:
            name: The name of image
            steps: Deprecated: Please use `.style.steps` instead. Number of iterations used to generate the output. Higher values improve quality and increase the strength of the prompt but increase processing time.
            assets: Provide the assets for photo editor
            resolution: The resolution of the final output image. The allowed value is based on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
            style: V1AiPhotoEditorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_photo_editor.create(
            assets={"image_file_path": "api-assets/id/1234.png"},
            resolution=768,
            style={
                "image_description": "A photo of a person",
                "likeness_strength": 5.2,
                "negative_prompt": "painting, cartoon, sketch",
                "prompt": "A photo portrait of a person wearing a hat",
                "prompt_strength": 3.75,
                "steps": 4,
                "upscale_factor": 2,
                "upscale_fidelity": 0.5,
            },
            name="Photo Editor image",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "steps": steps,
                "assets": assets,
                "resolution": resolution,
                "style": style,
            },
            dump_with=params._SerializerV1AiPhotoEditorCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-photo-editor",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiPhotoEditorCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiPhotoEditorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        assets: params.V1AiPhotoEditorCreateBodyAssets,
        resolution: int,
        style: params.V1AiPhotoEditorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        steps: typing.Union[
            typing.Optional[int], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiPhotoEditorCreateResponse:
        """
        AI Photo Editor

        > **NOTE**: this API is still in early development stages, and should be avoided. Please reach out to us if you're interested in this API.

        Edit photo using AI. Each photo costs 10 frames.

        POST /v1/ai-photo-editor

        Args:
            name: The name of image
            steps: Deprecated: Please use `.style.steps` instead. Number of iterations used to generate the output. Higher values improve quality and increase the strength of the prompt but increase processing time.
            assets: Provide the assets for photo editor
            resolution: The resolution of the final output image. The allowed value is based on your subscription. Please refer to our [pricing page](https://magichour.ai/pricing) for more details
            style: V1AiPhotoEditorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_photo_editor.create(
            assets={"image_file_path": "api-assets/id/1234.png"},
            resolution=768,
            style={
                "image_description": "A photo of a person",
                "likeness_strength": 5.2,
                "negative_prompt": "painting, cartoon, sketch",
                "prompt": "A photo portrait of a person wearing a hat",
                "prompt_strength": 3.75,
                "steps": 4,
                "upscale_factor": 2,
                "upscale_fidelity": 0.5,
            },
            name="Photo Editor image",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "steps": steps,
                "assets": assets,
                "resolution": resolution,
                "style": style,
            },
            dump_with=params._SerializerV1AiPhotoEditorCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-photo-editor",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiPhotoEditorCreateResponse,
            request_options=request_options or default_request_options(),
        )



import typing
import typing_extensions

from magic_hour.core import (
    AsyncBaseClient,
    RequestOptions,
    SyncBaseClient,
    default_request_options,
    to_encodable,
    type_utils,
)
from magic_hour.types import models, params


class AiImageGeneratorClient:
    def __init__(self, *, base_client: SyncBaseClient):
        self._base_client = base_client

    def create(
        self,
        *,
        image_count: int,
        orientation: typing_extensions.Literal["landscape", "portrait", "square"],
        style: params.V1AiImageGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiImageGeneratorCreateResponse:
        """
        AI Images

        Create an AI image. Each image costs 5 frames.

        POST /v1/ai-image-generator

        Args:
            name: The name of image
            image_count: number to images to generate
            orientation: typing_extensions.Literal["landscape", "portrait", "square"]
            style: V1AiImageGeneratorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        client.v1.ai_image_generator.create(
            image_count=1,
            orientation="landscape",
            style={"prompt": "Cool image"},
            name="Ai Image image",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "image_count": image_count,
                "orientation": orientation,
                "style": style,
            },
            dump_with=params._SerializerV1AiImageGeneratorCreateBody,
        )
        return self._base_client.request(
            method="POST",
            path="/v1/ai-image-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiImageGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )


class AsyncAiImageGeneratorClient:
    def __init__(self, *, base_client: AsyncBaseClient):
        self._base_client = base_client

    async def create(
        self,
        *,
        image_count: int,
        orientation: typing_extensions.Literal["landscape", "portrait", "square"],
        style: params.V1AiImageGeneratorCreateBodyStyle,
        name: typing.Union[
            typing.Optional[str], type_utils.NotGiven
        ] = type_utils.NOT_GIVEN,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> models.V1AiImageGeneratorCreateResponse:
        """
        AI Images

        Create an AI image. Each image costs 5 frames.

        POST /v1/ai-image-generator

        Args:
            name: The name of image
            image_count: number to images to generate
            orientation: typing_extensions.Literal["landscape", "portrait", "square"]
            style: V1AiImageGeneratorCreateBodyStyle
            request_options: Additional options to customize the HTTP request

        Returns:
            Success

        Raises:
            ApiError: A custom exception class that provides additional context
                for API errors, including the HTTP status code and response body.

        Examples:
        ```py
        await client.v1.ai_image_generator.create(
            image_count=1,
            orientation="landscape",
            style={"prompt": "Cool image"},
            name="Ai Image image",
        )
        ```
        """
        _json = to_encodable(
            item={
                "name": name,
                "image_count": image_count,
                "orientation": orientation,
                "style": style,
            },
            dump_with=params._SerializerV1AiImageGeneratorCreateBody,
        )
        return await self._base_client.request(
            method="POST",
            path="/v1/ai-image-generator",
            auth_names=["bearerAuth"],
            json=_json,
            cast_to=models.V1AiImageGeneratorCreateResponse,
            request_options=request_options or default_request_options(),
        )



import pydantic
import typing_extensions


class V1AiClothesChangerCreateBodyAssets(typing_extensions.TypedDict):
    """
    Provide the assets for clothes changer
    """

    garment_file_path: typing_extensions.Required[str]
    """
    The image of the outfit. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file..
    """

    garment_type: typing_extensions.Required[
        typing_extensions.Literal["dresses", "lower_body", "upper_body"]
    ]

    person_file_path: typing_extensions.Required[str]
    """
    The image with the person. This value can be either the `file_path` field from the response of the [upload urls API](https://docs.magichour.ai/api-reference/files/generate-asset-upload-urls), or the url of the file..
    """


class _SerializerV1AiClothesChangerCreateBodyAssets(pydantic.BaseModel):
    """
    Serializer for V1AiClothesChangerCreateBodyAssets handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    garment_file_path: str = pydantic.Field(
        alias="garment_file_path",
    )
    garment_type: typing_extensions.Literal["dresses", "lower_body", "upper_body"] = (
        pydantic.Field(
            alias="garment_type",
        )
    )
    person_file_path: str = pydantic.Field(
        alias="person_file_path",
    )



from .v1_ai_clothes_changer_create_body import (
    V1AiClothesChangerCreateBody,
    _SerializerV1AiClothesChangerCreateBody,
)
from .v1_ai_clothes_changer_create_body_assets import (
    V1AiClothesChangerCreateBodyAssets,
    _SerializerV1AiClothesChangerCreateBodyAssets,
)
from .v1_ai_face_editor_create_body import (
    V1AiFaceEditorCreateBody,
    _SerializerV1AiFaceEditorCreateBody,
)
from .v1_ai_face_editor_create_body_assets import (
    V1AiFaceEditorCreateBodyAssets,
    _SerializerV1AiFaceEditorCreateBodyAssets,
)
from .v1_ai_face_editor_create_body_style import (
    V1AiFaceEditorCreateBodyStyle,
    _SerializerV1AiFaceEditorCreateBodyStyle,
)
from .v1_ai_gif_generator_create_body import (
    V1AiGifGeneratorCreateBody,
    _SerializerV1AiGifGeneratorCreateBody,
)
from .v1_ai_gif_generator_create_body_style import (
    V1AiGifGeneratorCreateBodyStyle,
    _SerializerV1AiGifGeneratorCreateBodyStyle,
)
from .v1_ai_headshot_generator_create_body import (
    V1AiHeadshotGeneratorCreateBody,
    _SerializerV1AiHeadshotGeneratorCreateBody,
)
from .v1_ai_headshot_generator_create_body_assets import (
    V1AiHeadshotGeneratorCreateBodyAssets,
    _SerializerV1AiHeadshotGeneratorCreateBodyAssets,
)
from .v1_ai_headshot_generator_create_body_style import (
    V1AiHeadshotGeneratorCreateBodyStyle,
    _SerializerV1AiHeadshotGeneratorCreateBodyStyle,
)
from .v1_ai_image_generator_create_body import (
    V1AiImageGeneratorCreateBody,
    _SerializerV1AiImageGeneratorCreateBody,
)
from .v1_ai_image_generator_create_body_style import (
    V1AiImageGeneratorCreateBodyStyle,
    _SerializerV1AiImageGeneratorCreateBodyStyle,
)
from .v1_ai_image_upscaler_create_body import (
    V1AiImageUpscalerCreateBody,
    _SerializerV1AiImageUpscalerCreateBody,
)
from .v1_ai_image_upscaler_create_body_assets import (
    V1AiImageUpscalerCreateBodyAssets,
    _SerializerV1AiImageUpscalerCreateBodyAssets,
)
from .v1_ai_image_upscaler_create_body_style import (
    V1AiImageUpscalerCreateBodyStyle,
    _SerializerV1AiImageUpscalerCreateBodyStyle,
)
from .v1_ai_meme_generator_create_body import (
    V1AiMemeGeneratorCreateBody,
    _SerializerV1AiMemeGeneratorCreateBody,
)
from .v1_ai_meme_generator_create_body_style import (
    V1AiMemeGeneratorCreateBodyStyle,
    _SerializerV1AiMemeGeneratorCreateBodyStyle,
)
from .v1_ai_photo_editor_create_body import (
    V1AiPhotoEditorCreateBody,
    _SerializerV1AiPhotoEditorCreateBody,
)
from .v1_ai_photo_editor_create_body_assets import (
    V1AiPhotoEditorCreateBodyAssets,
    _SerializerV1AiPhotoEditorCreateBodyAssets,
)
from .v1_ai_photo_editor_create_body_style import (
    V1AiPhotoEditorCreateBodyStyle,
    _SerializerV1AiPhotoEditorCreateBodyStyle,
)
from .v1_ai_qr_code_generator_create_body import (
    V1AiQrCodeGeneratorCreateBody,
    _SerializerV1AiQrCodeGeneratorCreateBody,
)
from .v1_ai_qr_code_generator_create_body_style import (
    V1AiQrCodeGeneratorCreateBodyStyle,
    _SerializerV1AiQrCodeGeneratorCreateBodyStyle,
)
from .v1_ai_talking_photo_create_body import (
    V1AiTalkingPhotoCreateBody,
    _SerializerV1AiTalkingPhotoCreateBody,
)
from .v1_ai_talking_photo_create_body_assets import (
    V1AiTalkingPhotoCreateBodyAssets,
    _SerializerV1AiTalkingPhotoCreateBodyAssets,
)
from .v1_animation_create_body import (
    V1AnimationCreateBody,
    _SerializerV1AnimationCreateBody,
)
from .v1_animation_create_body_assets import (
    V1AnimationCreateBodyAssets,
    _SerializerV1AnimationCreateBodyAssets,
)
from .v1_animation_create_body_style import (
    V1AnimationCreateBodyStyle,
    _SerializerV1AnimationCreateBodyStyle,
)
from .v1_face_swap_create_body import (
    V1FaceSwapCreateBody,
    _SerializerV1FaceSwapCreateBody,
)
from .v1_face_swap_create_body_assets import (
    V1FaceSwapCreateBodyAssets,
    _SerializerV1FaceSwapCreateBodyAssets,
)
from .v1_face_swap_photo_create_body import (
    V1FaceSwapPhotoCreateBody,
    _SerializerV1FaceSwapPhotoCreateBody,
)
from .v1_face_swap_photo_create_body_assets import (
    V1FaceSwapPhotoCreateBodyAssets,
    _SerializerV1FaceSwapPhotoCreateBodyAssets,
)
from .v1_files_upload_urls_create_body import (
    V1FilesUploadUrlsCreateBody,
    _SerializerV1FilesUploadUrlsCreateBody,
)
from .v1_files_upload_urls_create_body_items_item import (
    V1FilesUploadUrlsCreateBodyItemsItem,
    _SerializerV1FilesUploadUrlsCreateBodyItemsItem,
)
from .v1_image_background_remover_create_body import (
    V1ImageBackgroundRemoverCreateBody,
    _SerializerV1ImageBackgroundRemoverCreateBody,
)
from .v1_image_background_remover_create_body_assets import (
    V1ImageBackgroundRemoverCreateBodyAssets,
    _SerializerV1ImageBackgroundRemoverCreateBodyAssets,
)
from .v1_image_to_video_create_body import (
    V1ImageToVideoCreateBody,
    _SerializerV1ImageToVideoCreateBody,
)
from .v1_image_to_video_create_body_assets import (
    V1ImageToVideoCreateBodyAssets,
    _SerializerV1ImageToVideoCreateBodyAssets,
)
from .v1_image_to_video_create_body_style import (
    V1ImageToVideoCreateBodyStyle,
    _SerializerV1ImageToVideoCreateBodyStyle,
)
from .v1_lip_sync_create_body import V1LipSyncCreateBody, _SerializerV1LipSyncCreateBody
from .v1_lip_sync_create_body_assets import (
    V1LipSyncCreateBodyAssets,
    _SerializerV1LipSyncCreateBodyAssets,
)
from .v1_photo_colorizer_create_body import (
    V1PhotoColorizerCreateBody,
    _SerializerV1PhotoColorizerCreateBody,
)
from .v1_photo_colorizer_create_body_assets import (
    V1PhotoColorizerCreateBodyAssets,
    _SerializerV1PhotoColorizerCreateBodyAssets,
)
from .v1_text_to_video_create_body import (
    V1TextToVideoCreateBody,
    _SerializerV1TextToVideoCreateBody,
)
from .v1_text_to_video_create_body_style import (
    V1TextToVideoCreateBodyStyle,
    _SerializerV1TextToVideoCreateBodyStyle,
)
from .v1_video_to_video_create_body import (
    V1VideoToVideoCreateBody,
    _SerializerV1VideoToVideoCreateBody,
)
from .v1_video_to_video_create_body_assets import (
    V1VideoToVideoCreateBodyAssets,
    _SerializerV1VideoToVideoCreateBodyAssets,
)
from .v1_video_to_video_create_body_style import (
    V1VideoToVideoCreateBodyStyle,
    _SerializerV1VideoToVideoCreateBodyStyle,
)


__all__ = [
    "V1AiClothesChangerCreateBody",
    "V1AiClothesChangerCreateBodyAssets",
    "V1AiFaceEditorCreateBody",
    "V1AiFaceEditorCreateBodyAssets",
    "V1AiFaceEditorCreateBodyStyle",
    "V1AiGifGeneratorCreateBody",
    "V1AiGifGeneratorCreateBodyStyle",
    "V1AiHeadshotGeneratorCreateBody",
    "V1AiHeadshotGeneratorCreateBodyAssets",
    "V1AiHeadshotGeneratorCreateBodyStyle",
    "V1AiImageGeneratorCreateBody",
    "V1AiImageGeneratorCreateBodyStyle",
    "V1AiImageUpscalerCreateBody",
    "V1AiImageUpscalerCreateBodyAssets",
    "V1AiImageUpscalerCreateBodyStyle",
    "V1AiMemeGeneratorCreateBody",
    "V1AiMemeGeneratorCreateBodyStyle",
    "V1AiPhotoEditorCreateBody",
    "V1AiPhotoEditorCreateBodyAssets",
    "V1AiPhotoEditorCreateBodyStyle",
    "V1AiQrCodeGeneratorCreateBody",
    "V1AiQrCodeGeneratorCreateBodyStyle",
    "V1AiTalkingPhotoCreateBody",
    "V1AiTalkingPhotoCreateBodyAssets",
    "V1AnimationCreateBody",
    "V1AnimationCreateBodyAssets",
    "V1AnimationCreateBodyStyle",
    "V1FaceSwapCreateBody",
    "V1FaceSwapCreateBodyAssets",
    "V1FaceSwapPhotoCreateBody",
    "V1FaceSwapPhotoCreateBodyAssets",
    "V1FilesUploadUrlsCreateBody",
    "V1FilesUploadUrlsCreateBodyItemsItem",
    "V1ImageBackgroundRemoverCreateBody",
    "V1ImageBackgroundRemoverCreateBodyAssets",
    "V1ImageToVideoCreateBody",
    "V1ImageToVideoCreateBodyAssets",
    "V1ImageToVideoCreateBodyStyle",
    "V1LipSyncCreateBody",
    "V1LipSyncCreateBodyAssets",
    "V1PhotoColorizerCreateBody",
    "V1PhotoColorizerCreateBodyAssets",
    "V1TextToVideoCreateBody",
    "V1TextToVideoCreateBodyStyle",
    "V1VideoToVideoCreateBody",
    "V1VideoToVideoCreateBodyAssets",
    "V1VideoToVideoCreateBodyStyle",
    "_SerializerV1AiClothesChangerCreateBody",
    "_SerializerV1AiClothesChangerCreateBodyAssets",
    "_SerializerV1AiFaceEditorCreateBody",
    "_SerializerV1AiFaceEditorCreateBodyAssets",
    "_SerializerV1AiFaceEditorCreateBodyStyle",
    "_SerializerV1AiGifGeneratorCreateBody",
    "_SerializerV1AiGifGeneratorCreateBodyStyle",
    "_SerializerV1AiHeadshotGeneratorCreateBody",
    "_SerializerV1AiHeadshotGeneratorCreateBodyAssets",
    "_SerializerV1AiHeadshotGeneratorCreateBodyStyle",
    "_SerializerV1AiImageGeneratorCreateBody",
    "_SerializerV1AiImageGeneratorCreateBodyStyle",
    "_SerializerV1AiImageUpscalerCreateBody",
    "_SerializerV1AiImageUpscalerCreateBodyAssets",
    "_SerializerV1AiImageUpscalerCreateBodyStyle",
    "_SerializerV1AiMemeGeneratorCreateBody",
    "_SerializerV1AiMemeGeneratorCreateBodyStyle",
    "_SerializerV1AiPhotoEditorCreateBody",
    "_SerializerV1AiPhotoEditorCreateBodyAssets",
    "_SerializerV1AiPhotoEditorCreateBodyStyle",
    "_SerializerV1AiQrCodeGeneratorCreateBody",
    "_SerializerV1AiQrCodeGeneratorCreateBodyStyle",
    "_SerializerV1AiTalkingPhotoCreateBody",
    "_SerializerV1AiTalkingPhotoCreateBodyAssets",
    "_SerializerV1AnimationCreateBody",
    "_SerializerV1AnimationCreateBodyAssets",
    "_SerializerV1AnimationCreateBodyStyle",
    "_SerializerV1FaceSwapCreateBody",
    "_SerializerV1FaceSwapCreateBodyAssets",
    "_SerializerV1FaceSwapPhotoCreateBody",
    "_SerializerV1FaceSwapPhotoCreateBodyAssets",
    "_SerializerV1FilesUploadUrlsCreateBody",
    "_SerializerV1FilesUploadUrlsCreateBodyItemsItem",
    "_SerializerV1ImageBackgroundRemoverCreateBody",
    "_SerializerV1ImageBackgroundRemoverCreateBodyAssets",
    "_SerializerV1ImageToVideoCreateBody",
    "_SerializerV1ImageToVideoCreateBodyAssets",
    "_SerializerV1ImageToVideoCreateBodyStyle",
    "_SerializerV1LipSyncCreateBody",
    "_SerializerV1LipSyncCreateBodyAssets",
    "_SerializerV1PhotoColorizerCreateBody",
    "_SerializerV1PhotoColorizerCreateBodyAssets",
    "_SerializerV1TextToVideoCreateBody",
    "_SerializerV1TextToVideoCreateBodyStyle",
    "_SerializerV1VideoToVideoCreateBody",
    "_SerializerV1VideoToVideoCreateBodyAssets",
    "_SerializerV1VideoToVideoCreateBodyStyle",
]



import pydantic
import typing
import typing_extensions

from .v1_ai_image_generator_create_body_style import (
    V1AiImageGeneratorCreateBodyStyle,
    _SerializerV1AiImageGeneratorCreateBodyStyle,
)


class V1AiImageGeneratorCreateBody(typing_extensions.TypedDict):
    """
    V1AiImageGeneratorCreateBody
    """

    image_count: typing_extensions.Required[int]
    """
    number to images to generate
    """

    name: typing_extensions.NotRequired[str]
    """
    The name of image
    """

    orientation: typing_extensions.Required[
        typing_extensions.Literal["landscape", "portrait", "square"]
    ]

    style: typing_extensions.Required[V1AiImageGeneratorCreateBodyStyle]


class _SerializerV1AiImageGeneratorCreateBody(pydantic.BaseModel):
    """
    Serializer for V1AiImageGeneratorCreateBody handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    image_count: int = pydantic.Field(
        alias="image_count",
    )
    name: typing.Optional[str] = pydantic.Field(alias="name", default=None)
    orientation: typing_extensions.Literal["landscape", "portrait", "square"] = (
        pydantic.Field(
            alias="orientation",
        )
    )
    style: _SerializerV1AiImageGeneratorCreateBodyStyle = pydantic.Field(
        alias="style",
    )



import pydantic
import typing_extensions


class V1AiQrCodeGeneratorCreateBodyStyle(typing_extensions.TypedDict):
    """
    V1AiQrCodeGeneratorCreateBodyStyle
    """

    art_style: typing_extensions.Required[str]
    """
    To use our templates, pass in one of Watercolor, Cyberpunk City, Ink Landscape, Interior Painting, Japanese Street, Mech, Minecraft, Picasso Painting, Game Map, Spaceship, Chinese Painting, Winter Village, or pass any custom art style.
    """


class _SerializerV1AiQrCodeGeneratorCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1AiQrCodeGeneratorCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    art_style: str = pydantic.Field(
        alias="art_style",
    )



import pydantic
import typing
import typing_extensions


class V1ImageToVideoCreateBodyStyle(typing_extensions.TypedDict):
    """
    Attributed used to dictate the style of the output
    """

    high_quality: typing_extensions.NotRequired[bool]
    """
    Deprecated: Please use `quality_mode` instead. For backward compatibility, setting `high_quality: true` and `quality_mode: quick` will map to `quality_mode: studio`. Note: `quality_mode: studio` offers the same quality as `high_quality: true`.
    """

    prompt: typing_extensions.NotRequired[str]
    """
    The prompt used for the video.
    """

    quality_mode: typing_extensions.NotRequired[
        typing_extensions.Literal["quick", "studio"]
    ]
    """
    * `quick` - Fastest option for rapid results. Takes ~3 minutes per 5s of video.
    *  `studio` - Polished visuals with longer runtime. Takes ~8.5 minutes per 5s of video.
    """


class _SerializerV1ImageToVideoCreateBodyStyle(pydantic.BaseModel):
    """
    Serializer for V1ImageToVideoCreateBodyStyle handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    high_quality: typing.Optional[bool] = pydantic.Field(
        alias="high_quality", default=None
    )
    prompt: typing.Optional[str] = pydantic.Field(alias="prompt", default=None)
    quality_mode: typing.Optional[typing_extensions.Literal["quick", "studio"]] = (
        pydantic.Field(alias="quality_mode", default=None)
    )



import pydantic


class V1VideoProjectsGetResponseError(pydantic.BaseModel):
    """
    In the case of an error, this object will contain the error encountered during video render
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    code: str = pydantic.Field(
        alias="code",
    )
    """
    An error code to indicate why a failure happened.
    """
    message: str = pydantic.Field(
        alias="message",
    )
    """
    Details on the reason why a failure happened.
    """
